@@ -12,7 +12,6 @@
 #'
 #' @author Alex Chubaty
 #' @export
-#' @importFrom raster getValues
 #' @rdname inRange
 #'
 #' @examples
@@ -23,8 +22,8 @@
 inRange <- function(x, a = 0, b = 1) {
   if (is.null(x)) return(NULL) # is this desired behaviour?
   if (!is.numeric(x)) {
-    if (is(x, "Raster")) {
-      x <- getValues(x)
+    if (inherits(x, c("Raster", "SpatRaster"))) {
+      x <- as.vector(x[])
     } else {
       stop("x must be numeric.")
     }
